@@ -1,4 +1,14 @@
 /*
+ * main.c        1.4 11/9/95
+ *	Mixmaster now chdir's to mix_dir rather than prepending
+ *	That directory to every filename.
+ *	Magic strings now defined here rather than in mixmaster.h
+ *
+ *	-P prints out three lines, 
+ *		current mix_dir
+ *		filename containing the list of remailers
+ *		current version of Mixmaster.
+ *
  * main.c        1.3 5/10/95
  *	-t and To: replaces destination on command line
  *
@@ -28,8 +38,24 @@
 #include "mixmaster.h"
 #include "crypt.h"
 
+char  VERSION[] =  "2.0.3";
+char  remailer_type[] = "Remailer-Type: Mixmaster ";
+char  begin_remailer[]="-----BEGIN REMAILER MESSAGE-----\n";
+char  end_remailer[]="-----END REMAILER MESSAGE-----\n";
+char  two_n [] = "\n\n";
+char  begin_armour[]="-----BEGIN PGP MESSAGE-----\nVersion: ";
+char  end_armour[]="-----END PGP MESSAGE-----\n";
+char  begin_signed[]="-----BEGIN PGP SIGNED MESSAGE-----\n\n";
+char  begin_signature[]="\n-----BEGIN PGP SIGNATURE-----\nVersion: ";
+char  end_signature[]="-----END PGP SIGNATURE-----\n";
+char  begin_key[]="-----Begin Mix Key-----\n";
+char  end_key[]="-----End Mix Key-----\n";
+char  intermed_hop[]="-----Intermediate Hop-----\n";
+char  final_hop[]="-----Final Hop-----\n";
 
-char    mix_dir[80] = "/usr9/loki/Devel/Mix";
+
+char    mix_dir[256] = "/usr9/loki/Devel/Mix";
+char    cur_dir[256];
 char    KEYFILE[256] = "mix.key";
 char    HELPFILE[256]="mix.help";
 char    REMAILERNAME[80] = "The Nately Remailer";
@@ -38,13 +64,13 @@ char    REMAILERADDR[80] = "mixmaster@nately.ucsd.edu";
 char    COMPLAINTS[80] =  "complaints@nately.ucsd.edu";
 int     POOLSIZE = 0;
 char    REMAILERLIST[80] = "type2.list";
-char    IDLOG[80] = "packet.id.log";
+char    IDLOG[80] = "id.log";
 char    STATS[80] = "stats.log";
 /* the -t option tells sendmail to expect a To: header in stdin */
 char    SENDMAIL[80] = "/usr/lib/sendmail -t";
 char    NEWS[80] = "";
 char    ABILITIES[80] = "capabilities";
-char    MAILtoNEWS[80] = "@news.demon.co.uk";
+char    MAILtoNEWS[80] = "mail2news@c2.org";
 char	TYPE1[256] = ""; /* Default is no Type 1 support */
 
 
@@ -64,6 +90,14 @@ value */
           strcpy(mix_dir,foo);
         }
 
+	if(getcwd(cur_dir,256) == NULL) { /*could not get current dir */
+	  fprintf(stderr,"Could not get current directory!\n");
+	  strcpy(cur_dir,mix_dir); /* So set cur_dir to mix_dir */
+	}
+	if(chdir(mix_dir) != 0) {
+	  fprintf(stderr,"Error changing to mix_dir %s\n",mix_dir);
+        }
+
         if((fptr = (FILE *)open_mix_file("mixmaster.conf","r"))==NULL) {
           return(-1);
         } else {
@@ -71,6 +105,9 @@ value */
            if(line[0] != '#' && strlen(line) > 2) {
             if(strstr(line,"mix_dir")!=NULL) {
               sscanf(line,"%s %s",junk,mix_dir);
+	      if(chdir(mix_dir) != 0) {
+	        fprintf(stderr,"Error changing to mix_dir %s\n",mix_dir);
+              }
             }
             if(strncmp(line,"help",4)==0){
               sscanf(line,"%s %s",junk,HELPFILE);
@@ -353,6 +390,7 @@ main(int argc, char *argv[])
         for(i=1; i<argc;i++) {
           if(strchr(argv[i],'-')!=NULL) {
             if(strstr(argv[i],"-R")!=NULL) rem=1;
+            if(strstr(argv[i],"-r")!=NULL) rem=1; /* some aliases don't allow caps */
             if(strstr(argv[i],"-S")!=NULL) snd=1;
             if(strstr(argv[i],"-L")!=NULL) lat=1;
             if(strstr(argv[i],"-G")!=NULL) gen=1;
@@ -369,6 +407,7 @@ main(int argc, char *argv[])
         if(path) {
           printf("%s\n",mix_dir); /* note no trailing slash here */
           printf("%s\n",REMAILERLIST);
+	  printf("%s\n",VERSION);
         }
         if(type_list) {
           strcpy(line,mix_dir);
