@@ -1,4 +1,9 @@
 /*
+ * mixmaster.h        1.2 11/2/95
+ *	Some new comments, PASSPHRASE no longer
+ *	set here, now set at compile time.
+ *	magic strings now declared in main.c
+ *
  * mixmaster.h        1.1 4/30/95
  *
  *      (c) Copyright 1995 by Lance Cottrell. All right reserved.
@@ -13,13 +18,9 @@
  *
  */
 
-#ifndef PASSPHRASE
-#define PASSPHRASE "foobar"
-#endif
+/*Expiration time for old packets and id numbers in seconds*/
 #define PACKETEXP 604800
 #define IDEXP 604800
-#define SPOOL "/home/bob/Mix"
-
 
 #include <fcntl.h>
 #include <string.h>
@@ -32,6 +33,13 @@
 #include <sys/time.h>
 #include <unistd.h>
 
+#ifndef PASSPHRASE
+#define PASSPHRASE "none"
+#endif
+#ifndef SPOOL
+#define SPOOL "/u1/ronco/Mixmaster/Mix"
+#endif
+
 
 #define PACKETSIZE 10236 /* 10240 - 4 (length bytes) */
 #define HEADERSIZE 512
@@ -46,25 +54,23 @@
 #define FL_STATS   8
 
 
+extern  char  VERSION[];
+extern  char  remailer_type[];
+extern  char  begin_remailer[];
+extern  char  end_remailer[];
+extern  char  two_n [];
+extern  char  begin_armour[];
+extern  char  end_armour[];
+extern  char  begin_signed[];
+extern  char  begin_signature[];
+extern  char  end_signature[];
+extern  char  begin_key[];
+extern  char  end_key[];
+extern  char  intermed_hop[];
+extern  char  final_hop[];
 
-static	char	VERSION[] =  "2.0.2";
-static  char    remailer_type[] = "Remailer-Type: Mixmaster ";
-static  char    begin_remailer[]="-----BEGIN REMAILER MESSAGE-----\n";
-static  char    end_remailer[]="-----END REMAILER MESSAGE-----\n";
-static  char    two_n [] = "\n\n";
-static  char    begin_armour[]="-----BEGIN PGP MESSAGE-----\nVersion: ";
-static  char    end_armour[]="-----END PGP MESSAGE-----\n";
-static  char    begin_signed[]="-----BEGIN PGP SIGNED MESSAGE-----\n\n";
-static  char    begin_signature[]="\n-----BEGIN PGP SIGNATURE-----\nVersion: ";
-static  char    end_signature[]="-----END PGP SIGNATURE-----\n";
-static	char	begin_key[]="-----Begin Mix Key-----\n";
-static	char	end_key[]="-----End Mix Key-----\n";
-static	char	intermed_hop[]="-----Intermediate Hop-----\n";
-static	char	final_hop[]="-----Final Hop-----\n";
-
-
-
-extern char 	mix_dir[];
+extern char mix_dir[];
+extern char cur_dir[];
 extern char KEYFILE[];
 extern char REMAILERADDR[];
 extern char REMAILERNAME[];
