@@ -1,7 +1,9 @@
 /*
- * stats.c        1.2 9/10/95
+ * stats.c        1.3 11/22/95
+ *    	Info on news posting setings printed at end of stats.
  * 
- * 1.2	Added automatic creation of non-existant stats.log file,
+ * stats.c        1.2 9/10/95
+ *    	Added automatic creation of non-existant stats.log file,
  *      and reinit to default if there is a problem
  *      Sendmail now uses To: not command line for destination.
  *
@@ -153,7 +155,6 @@ void stats(int flag, char *address)
     mix_unlock("stats",statlock);
     return;
   }
-  flock(fileno(datafile),LOCK_EX);
 
   fprintf(datafile,"%d\n",currenthour);
   fprintf(datafile,"%d %d %d\n",ccm,ccpgp,ccl);
@@ -161,7 +162,6 @@ void stats(int flag, char *address)
     fprintf(datafile,"%s %d %d %d %d\n",month[x],date[x],m[x],p[x],l[x]);
   }
 
-  flock(fileno(datafile),LOCK_UN);
   fclose(datafile);
   mix_unlock("stats",statlock);
 
@@ -203,6 +203,21 @@ void stats(int flag, char *address)
        fprintf(pp,"Number of messages remailed in last 24 hours: %d\n",ccm);
     }
     fprintf(pp,"Current message reordering pool size: %d\n",POOLSIZE);
+
+    /* Report on this remailer's ability to post to news */
+    if (strlen(NEWS) > 1) {
+      if(strstr(NEWS,"mail-to-news")) {
+	fprintf(pp,"This remailer supports posting to news through the\n");
+	fprintf(pp,"%s mail-to-news gateway.\n",MAILtoNEWS);
+	fprintf(pp,"These are not entirely reliable, you should test to be\n");
+	fprintf(pp,"sure that you can reach the groups you want\n");
+      } else {
+	fprintf(pp,"This remailer supports direct posting to news.\n");
+	fprintf(pp,"Remember that not all news servers support all groups.\n");
+      }
+    } else {
+      fprintf(pp,"This remailer does not support posting to news.\n");
+    }
     pclose(pp);
   }
 }
