@@ -1,4 +1,10 @@
 /*
+ * type2.c        2.6 11/2/95
+ *	Destination and subject fields filled out
+ *	with nulls to ensure no leakage of information.
+ *	new command line flag -O.
+ *	  same as -o but puts a "To: " line at the top
+ *
  * type2.c        2.5 9/20/95
  *	Remailer choice of 0 causes mixmaster to choose a remailer
  *	at random from type2.list
@@ -77,13 +83,17 @@ int merge_packets(BUFFER *body, byte *messageID, byte packet, byte numpackets)
 
 	  gettimeofday(&now,0);
 	  seconds = now.tv_sec;
-	  tmparray[0]== seconds && 0xFF; /* low byte */
+/*	  tmparray[0]= seconds % 256; /* low byte */
+	  tmparray[0]= seconds & 0xFF; /* low byte */
 	  seconds = seconds / 256;
-	  tmparray[1]== seconds && 0xFF; /* second */
+/*	  tmparray[1]= seconds % 256; /* second */
+	  tmparray[1]= seconds & 0xFF; /* second */
 	  seconds = seconds / 256;
-	  tmparray[2]== seconds && 0xFF; /* third */
+/*	  tmparray[2]= seconds % 256; /* third */
+	  tmparray[2]= seconds & 0xFF; /* third */
 	  seconds = seconds / 256;
-	  tmparray[3]== seconds && 0xFF; /* high byte */
+/*	  tmparray[3]= seconds % 256; /* high byte */
+	  tmparray[3]= seconds & 0xFF; /* high byte */
 
 	  fwrite(tmparray,4, 1, out); /* write new timestamp */
 	  fwrite(messageID,16,1,out);
@@ -259,13 +269,17 @@ int merge_packets(BUFFER *body, byte *messageID, byte packet, byte numpackets)
 	  if((out = open_mix_file(filename,"w"))==NULL) return(-3);
 	  gettimeofday(&now,0);
 	  seconds = now.tv_sec;
-	  tmparray[0]== seconds && 0xFF; /* low byte */
+/*	  tmparray[0]= seconds % 256; /* low byte */
+	  tmparray[0]= seconds & 0xFF; /* low byte */
 	  seconds = seconds / 256;
-	  tmparray[1]== seconds && 0xFF; /* second */
+/*	  tmparray[1]= seconds % 256; /* second */
+	  tmparray[1]= seconds & 0xFF; /* second */
 	  seconds = seconds / 256;
-	  tmparray[2]== seconds && 0xFF; /* third */
+/*	  tmparray[2]= seconds % 256; /* third */
+	  tmparray[2]= seconds & 0xFF; /* third */
 	  seconds = seconds / 256;
-	  tmparray[3]== seconds && 0xFF; /* high byte */
+/*	  tmparray[3]= seconds % 256; /* high byte */
+	  tmparray[3]= seconds & 0xFF; /* high byte */
 
 	  fwrite(tmparray,4, 1, out); /* write new timestamp */
 	  fwrite(messageID,16,1,out);
@@ -314,7 +328,7 @@ int check_packetID(byte *ID)
 	}
 	/* ID number is new */
 	fwrite(line,strlen(line),1,fptr);
-	fprintf(fptr," %i \n",now.tv_sec);
+	fprintf(fptr," %u \n",now.tv_sec);
 	mix_unlock(IDLOG, lockptr);
 	fclose(fptr);
 	return(1);
@@ -521,7 +535,13 @@ printf("intermed hop\n"); /* debug */
 	  fprintf(fptr,"temp");  /* make sure the file is created */
 	  fclose(fptr);
 	  if(check_packetID(packetID)){
-	    if(send_new_packet(headers,body,address,line,0)<0) return(-1);
+	    if(send_new_packet(headers,body,address,line,0,0)<0) {
+	      unlink(line);
+	      mix_unlock("mail",lockptr);
+	      return(-1);
+	    }
+	  } else {
+	    unlink(line);
 	  }
 	  mix_unlock("mail",lockptr);
 
@@ -599,7 +619,6 @@ printf("final hop\n"); /* debug */
 	  /* decompression would go here */
 
 	  fwrite(b2->message,1,b2->length,fptr);
-	  flock(fileno(fptr),LOCK_UN);
 	  fclose(fptr);
 	  mix_unlock("mail",lockptr);
 
@@ -644,6 +663,7 @@ int read_remailer_list(FILE *ptr, REMAILER *list)
 	num = 0;
 	while(fgets(line,255,ptr)!=NULL) {
 	  num++;
+	  memset(&list[num], 0, sizeof(list[num]));
 	  sscanf(line,"%s %s %s %s",list[num].shortname,list[num].name,
 	  	tmp,list[num].version);
 	  sscanf(tmp,"%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x%2x",
@@ -657,10 +677,10 @@ int read_remailer_list(FILE *ptr, REMAILER *list)
 }
 
 /* send packet just generated */
-int send_new_packet(headbuff,bodybuff, address,outfile, client)
+int send_new_packet(headbuff,bodybuff, address,outfile,outfileflag, client)
 BUFFER	**headbuff, *bodybuff;
 char	*outfile,*address;
-int	client;
+int	client,outfileflag;
 {
 	int	i,j,k,n,len;
 	BUFFER	*outbuffer,*tmpbuffer;
@@ -681,7 +701,7 @@ int	client;
 	/* build output file */
 	outbuffer = new_buffer();
 	/* If either client being mailed directly, or not client then add a To: line */
-	if(strlen(outfile)<=1 || !client) {
+	if(strlen(outfile)<=1 || !client || outfileflag) {
  	  add_to_buffer(outbuffer, "To: ", strlen("To: "));
 	  add_to_buffer(outbuffer, address, strlen(address));
 	}
@@ -728,7 +748,7 @@ int	client;
             return(-1);
           }
           fwrite(outbuffer->message,sizeof(char),outbuffer->length,fptr);
-	  fclose(fptr);
+	  pclose(fptr);
 	} else if(strstr(outfile,"stdout")) {
           fwrite(outbuffer->message,sizeof(char),outbuffer->length,stdout);
 	} else {
@@ -739,7 +759,6 @@ int	client;
 	    fprintf(fptr,"%s\nEND\n",address);
 	  }
           fwrite(outbuffer->message,sizeof(char),outbuffer->length,fptr);
-	  flock(fileno(fptr),LOCK_UN); /* possible locked before calling */
 	  fclose(fptr);
 	}
 	free_buffer(outbuffer);
@@ -747,9 +766,9 @@ int	client;
 }
 
 /* this actualy makes the message block and sends it */
-int build_message(in_ptr, numdest, destination, remailer_chain, numsub, subject, outfile, remailer_list, num_remailers)
+int build_message(in_ptr, numdest, destination, remailer_chain, numsub, subject, outfile, outfileflag, remailer_list, num_remailers)
 FILE	*in_ptr;
-int	*remailer_chain,num_remailers;
+int	*remailer_chain,num_remailers, outfileflag;
 byte numsub, numdest;
 char	**destination, **subject, *outfile;
 REMAILER 	*remailer_list;
@@ -979,9 +998,9 @@ REMAILER 	*remailer_list;
 	  } /* hop loop for a given packet */
 	  if(strlen(outfile) > 1 && !strstr(outfile,"stdout") && numpackets > 1) {
 	    sprintf(line,"%s.%d",outfile,packet);
-	    send_new_packet(headbuff,bodybuff, remailer_list[abs(remailer_chain[1])].name,line,1);
+	    send_new_packet(headbuff,bodybuff, remailer_list[abs(remailer_chain[1])].name,line,outfileflag,1);
 	  } else {
-	    send_new_packet(headbuff,bodybuff, remailer_list[abs(remailer_chain[1])].name,outfile,1);
+	    send_new_packet(headbuff,bodybuff, remailer_list[abs(remailer_chain[1])].name,outfile,outfileflag,1);
 	  }
 	} /* end loop proccessing packets */
 	free_buffer(bodybuff);
@@ -1025,7 +1044,7 @@ int	chain_2(int argc, char *argv[])
 	char	*subject[80];
 	int	remailer_chain[80];
 	byte	numdest=0, numsub=0;
-	int	i,j,k,status,num_remailers;
+	int	i,j,k,status,num_remailers,outfileflag=0;
 	REMAILER remailer_list[256];
 	int	filter = 0;
 
@@ -1039,7 +1058,7 @@ int	chain_2(int argc, char *argv[])
 
 	/* what is in those arguments */
 	/* Here is the expected format */
-	/* mixmaster [-c][-f][filename][-o outfile][-to who@where][-s "subject"][-l 1 2 3 4] */
+	/* mixmaster [-c][-f][filename][-[o,O] outfile][-to who@where][-s "subject"][-l 1 2 3 4] */
 	/* if no outfile given, then pipe to sendmail. outfile = stdout send to stdout */
 	for(i=1; i<argc; i++) {
 	  if(strstr(argv[i],"-c")) {
@@ -1049,7 +1068,7 @@ int	chain_2(int argc, char *argv[])
 	    printf("Mixmaster (C) Copyright Lance M. Cottrell 1995\n");
 	    printf("Released under the GNU public license.\n");
 	    printf("Client Mode command line arguments:\n");
-	    printf("mixmaster [-c][-f][filename][-o outfile][-to who@where][-s \"subject\"][-l 1 2 3 4]\n");
+	    printf("mixmaster [-c][-f][filename][-[o,O] outfile][-to who@where][-s \"subject\"][-l 1 2 3 4]\n");
 	    exit(-1);
 	  } else if(strstr(argv[i],"-f")) {
 	    /* set filter mode */
@@ -1057,18 +1076,31 @@ int	chain_2(int argc, char *argv[])
 	  } else if(strstr(argv[i],"-s")) {
 	    if(i < argc - 1) i++;
 	    subject[0] = (char *)malloc(80 * sizeof(char));
-	    strcpy(subject[0],"Subject: ");
+	    strncpy(subject[0],"Subject: ", 79);
+	    subject[0][79]='\0';
 	    strcat(subject[0],argv[i]);
             j= strlen(subject[0]);
 	    if(strstr(subject[0],"\r")) subject[0][j-1]=0;
 	    numsub = 1;
 	  } else if(strstr(argv[i],"-o")) {
 	    if(i < argc - 1) i++;
-	    strcpy(outfile,argv[i]);
+	    if(argv[i][0] == '/') {
+	      strcpy(outfile,argv[i]);
+	    } else {
+	      sprintf(outfile, "%s/%s", cur_dir, argv[i]);
+	    }
+	  } else if(strstr(argv[i],"-O")) {
+	    if(i < argc - 1) i++;
+	    if(argv[i][0] == '/') {
+	      strcpy(outfile,argv[i]);
+	    } else {
+	      sprintf(outfile, "%s/%s", cur_dir, argv[i]);
+	    }
+	    outfileflag=1;
 	  } else if(strstr(argv[i],"-to")) {
 	    if(i < argc - 1) i++;
 	    destination[0] = (char *)malloc(80 * sizeof(char));
-	    strcpy(destination[0],argv[i]);
+	    strncpy(destination[0],argv[i],79); destination[0][79]='\0';
             j= strlen(destination[0]);
 	    if(strstr(destination[0],"\r")) destination[0][j-1]=0;
 	    numdest = 1;
@@ -1106,7 +1138,8 @@ int	chain_2(int argc, char *argv[])
 	    if(line[i-1] < ' ') line[i-1] = 0;
 	    if(strlen(line) >= 2) {
 	      destination[numdest] = (char *)malloc(80 * sizeof(char));
-	      strcpy(destination[numdest],line);
+	      strncpy(destination[numdest],line,79);
+	      destination[numdest][79] = '\0';
 	      numdest++;
 	    }
 	  } while(strlen(line) >=2 || numdest == 0);
@@ -1123,7 +1156,8 @@ int	chain_2(int argc, char *argv[])
 	    if(line[i-1] < ' ') line[i-1] = 0;
 	    if(strlen(line) >= 2) {
 	      subject[numsub] = (char *)malloc(80 * sizeof(char));
-	      strcpy(subject[numsub],line);
+	      strncpy(subject[numsub],line,79);
+	      subject[numsub][79] = '\0';
 	      numsub++;
 	    }
 	  } while(strlen(line) >=2);
@@ -1146,7 +1180,14 @@ int	chain_2(int argc, char *argv[])
 	if(strcmp(filename,"stdin")==0 || strlen(filename)==0) {
 	  in = stdin;
 	} else {
-	  if((in=fopen(filename,"r"))==NULL) {
+	  if(filename[0] != '/') { /* not a full pathname */
+	    strcpy(line,cur_dir);
+	    strcat(line,"/");
+	    strcat(line,filename);
+	  } else {
+	    strcpy(line,filename);
+	  }
+	  if((in=fopen(line,"r"))==NULL) {
 	    fprintf(stderr,"Could not open file %s\n",filename);
 	    return(-1);
 	  }
@@ -1163,7 +1204,7 @@ for(i=1;i<=remailer_chain[0];i++) printf("remailer %d\n",remailer_chain[i]); /*d
 for(i=0;i<numsub;i++) printf("header %d  %s\n",i,subject[i]); /*debug*/
 #endif
 
-	status = build_message(in, numdest, destination, remailer_chain, numsub, subject, outfile,remailer_list,num_remailers);
+	status = build_message(in, numdest, destination, remailer_chain, numsub, subject, outfile,outfileflag,remailer_list,num_remailers);
 
 	fclose(in);
 }
